# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetMaterializedFeaturesFeatureTagsResult',
    'AwaitableGetMaterializedFeaturesFeatureTagsResult',
    'get_materialized_features_feature_tags',
    'get_materialized_features_feature_tags_output',
]

@pulumi.output_type
class GetMaterializedFeaturesFeatureTagsResult:
    """
    A collection of values returned by getMaterializedFeaturesFeatureTags.
    """
    def __init__(__self__, feature_name=None, feature_tags=None, id=None, page_size=None, table_name=None):
        if feature_name and not isinstance(feature_name, str):
            raise TypeError("Expected argument 'feature_name' to be a str")
        pulumi.set(__self__, "feature_name", feature_name)
        if feature_tags and not isinstance(feature_tags, list):
            raise TypeError("Expected argument 'feature_tags' to be a list")
        pulumi.set(__self__, "feature_tags", feature_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if table_name and not isinstance(table_name, str):
            raise TypeError("Expected argument 'table_name' to be a str")
        pulumi.set(__self__, "table_name", table_name)

    @_builtins.property
    @pulumi.getter(name="featureName")
    def feature_name(self) -> _builtins.str:
        return pulumi.get(self, "feature_name")

    @_builtins.property
    @pulumi.getter(name="featureTags")
    def feature_tags(self) -> Sequence['outputs.GetMaterializedFeaturesFeatureTagsFeatureTagResult']:
        return pulumi.get(self, "feature_tags")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "page_size")

    @_builtins.property
    @pulumi.getter(name="tableName")
    def table_name(self) -> _builtins.str:
        return pulumi.get(self, "table_name")


class AwaitableGetMaterializedFeaturesFeatureTagsResult(GetMaterializedFeaturesFeatureTagsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMaterializedFeaturesFeatureTagsResult(
            feature_name=self.feature_name,
            feature_tags=self.feature_tags,
            id=self.id,
            page_size=self.page_size,
            table_name=self.table_name)


def get_materialized_features_feature_tags(feature_name: Optional[_builtins.str] = None,
                                           page_size: Optional[_builtins.int] = None,
                                           table_name: Optional[_builtins.str] = None,
                                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMaterializedFeaturesFeatureTagsResult:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.int page_size: The maximum number of results to return
    """
    __args__ = dict()
    __args__['featureName'] = feature_name
    __args__['pageSize'] = page_size
    __args__['tableName'] = table_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getMaterializedFeaturesFeatureTags:getMaterializedFeaturesFeatureTags', __args__, opts=opts, typ=GetMaterializedFeaturesFeatureTagsResult).value

    return AwaitableGetMaterializedFeaturesFeatureTagsResult(
        feature_name=pulumi.get(__ret__, 'feature_name'),
        feature_tags=pulumi.get(__ret__, 'feature_tags'),
        id=pulumi.get(__ret__, 'id'),
        page_size=pulumi.get(__ret__, 'page_size'),
        table_name=pulumi.get(__ret__, 'table_name'))
def get_materialized_features_feature_tags_output(feature_name: Optional[pulumi.Input[_builtins.str]] = None,
                                                  page_size: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                                  table_name: Optional[pulumi.Input[_builtins.str]] = None,
                                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetMaterializedFeaturesFeatureTagsResult]:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.int page_size: The maximum number of results to return
    """
    __args__ = dict()
    __args__['featureName'] = feature_name
    __args__['pageSize'] = page_size
    __args__['tableName'] = table_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getMaterializedFeaturesFeatureTags:getMaterializedFeaturesFeatureTags', __args__, opts=opts, typ=GetMaterializedFeaturesFeatureTagsResult)
    return __ret__.apply(lambda __response__: GetMaterializedFeaturesFeatureTagsResult(
        feature_name=pulumi.get(__response__, 'feature_name'),
        feature_tags=pulumi.get(__response__, 'feature_tags'),
        id=pulumi.get(__response__, 'id'),
        page_size=pulumi.get(__response__, 'page_size'),
        table_name=pulumi.get(__response__, 'table_name')))
